@@ -443,9 +443,7 @@ class Engine:
         if self.verbose is True:
             logger.info("Computation is not parallel")
         t = time()
-        results = []
-        for e in collection:
-            results.append(self._pre_launch(e, method, False, kwargs))
+        results = [self._pre_launch(e, method, False, kwargs) for e in collection]
 
         return self._finish_job(
             _Job(results=results, client=None, method_name=method.__name__, starttime=t, batched=False)
@@ -562,7 +560,7 @@ class Engine:
         into one.
         * gather_method (Callable). If 'gather' is True, use this method to gather the object intead of a basis list
         comprehension
-        * shared (dict). Dictionnary of pd.DataFrame, pd.Series or np.ndarray that should be written to disk and shared
+        * share (dict). Dictionnary of pd.DataFrame, pd.Series or np.ndarray that should be written to disk and shared
         by giving a path to the method.
         * init_method (dict). Dictionnary of the form {"method": a_method, "kwargs": {...}}. The given method will be
         executed in each process using given "kwargs"
@@ -589,7 +587,7 @@ class Engine:
             logger.info(f"Iterable has a length of {len(collection)}")
         indexes_to_print = self._make_counter(collection, method.__name__)
         collection = [
-            (item, None) if i not in indexes_to_print else (item, indexes_to_print[i])
+            (item, None) if i + 1 not in indexes_to_print else (item, indexes_to_print[i + 1])
             for i, item in enumerate(collection)
         ]
         if len(collection) == 0:
@@ -705,6 +703,8 @@ class Engine:
 
                     if self.path_shared is None:
                         self.path_shared = self.__class__.PATH(gettempdir(), fs="local") / "adparallelengine_temp"
+                        if self.path_shared.isdir():
+                            self.path_shared.rmdir()
                     if not self.path_shared.isdir():
                         self.path_shared.mkdir()
                     p = (self.path_shared / item).with_suffix(".parquet")
@@ -792,10 +792,13 @@ class Engine:
                     in_init_method = False
                     if item in dict(inspect.signature(method).parameters):
                         in_method = True
-                    if "init_method" in kwargs and item in dict(
-                        inspect.signature(kwargs["init_method"]["method"]).parameters
-                    ):
-                        in_init_method = True
+                    if "init_method" in kwargs:
+                        if "method" not in kwargs["init_method"]:
+                            raise ValueError("If using kwarg 'init_method' in Engine, must specify the 'method' key")
+                        if item in dict(
+                            inspect.signature(kwargs["init_method"]["method"]).parameters
+                        ):
+                            in_init_method = True
                     if not in_init_method and not in_method:
                         raise ValueError(
                             f"Shared keyword argument {item} is not valid for the given method and init_method"
@@ -822,10 +825,13 @@ class Engine:
                 in_init_method = False
                 if item in dict(inspect.signature(method).parameters):
                     in_method = True
-                if "init_method" in kwargs and item in dict(
-                    inspect.signature(kwargs["init_method"]["method"]).parameters
-                ):
-                    in_init_method = True
+                if "init_method" in kwargs:
+                    if "method" not in kwargs["init_method"]:
+                        raise ValueError("If using kwarg 'init_method' in Engine, must specify the 'method' key")
+                    if item in dict(
+                            inspect.signature(kwargs["init_method"]["method"]).parameters
+                    ):
+                        in_init_method = True
                 if not in_init_method and not in_method:
                     raise ValueError(f"Keyword argument {item} is not valid for the given method and init_method")
                 if in_init_method:
@@ -844,11 +850,14 @@ class Engine:
             if not batched:
                 return _launch(method, elements, kwargs)
 
-            to_ret, times, mems = np.array([_launch(method, element, kwargs) for element in elements]).T
+            to_ret, times, mems = np.array([_launch(method, element, kwargs) for element in elements], dtype="object").T
 
             return to_ret, times, mems
         except Exception as e:
-            logger.critical(f"Process caught an error : {''.join(tb.format_exception(None, e, e.__traceback__))}")
+            logger.critical(
+                f"Process caught an error on element(s) {elements}"
+                f" : {''.join(tb.format_exception(None, e, e.__traceback__))}"
+            )
             raise e
 
 
